@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright © 2001-2014 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2017 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ using namespace Akonadi;
 namespace
 {
 bool            refreshAlarmsQueued = false;
-QDBusInterface* korgInterface = Q_NULLPTR;
+QDBusInterface* korgInterface = nullptr;
 
 struct UpdateStatusData
 {
@@ -150,7 +150,7 @@ QString uidKOrganizer(const QString& eventID);
 namespace KAlarm
 {
 
-Private* Private::mInstance = Q_NULLPTR;
+Private* Private::mInstance = nullptr;
 
 /******************************************************************************
 * Display a main window with the specified event selected.
@@ -334,7 +334,7 @@ bool addArchivedEvent(KAEvent& event, Collection* collection)
         newev->setCreatedDateTime(KDateTime::currentUtcDateTime());   // time stamp to control purging
     }
     // Note that archived resources are automatically saved after changes are made
-    if (!cal->addEvent(newevent, Q_NULLPTR, false, collection))
+    if (!cal->addEvent(newevent, nullptr, false, collection))
         return false;
     event = *newev;   // update event ID etc.
 
@@ -760,7 +760,7 @@ void purgeArchive(int purgeDays)
 */
 QVector<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
 {
-    AlarmListModel* mdl = Q_NULLPTR;
+    AlarmListModel* mdl = nullptr;
     if (!model)
         model = &mdl;
     if (!*model)
@@ -966,7 +966,7 @@ bool editNewAlarm(const QString& templateName, QWidget* parent)
 */
 void editNewTemplate(EditAlarmDlg::Type type, QWidget* parent)
 {
-    ::editNewTemplate(type, Q_NULLPTR, parent);
+    ::editNewTemplate(type, nullptr, parent);
 }
 
 /******************************************************************************
@@ -977,6 +977,25 @@ void editNewTemplate(const KAEvent* preset, QWidget* parent)
     ::editNewTemplate(EditAlarmDlg::Type(0), preset, parent);
 }
 
+/******************************************************************************
+* Find the identity of the desktop we are running on.
+*/
+QString currentDesktopIdentityName()
+{
+    return QProcessEnvironment::systemEnvironment().value(QStringLiteral("XDG_CURRENT_DESKTOP"));
+}
+
+/******************************************************************************
+* Find the identity of the desktop we are running on.
+*/
+Desktop currentDesktopIdentity()
+{
+    const QString desktop = currentDesktopIdentityName();
+    if (desktop == QStringLiteral("KDE"))    return Desktop::Kde;
+    if (desktop == QStringLiteral("Unity"))  return Desktop::Unity;
+    return Desktop::Other;
+}
+
 /******************************************************************************
 * Check the config as to whether there is a wake-on-suspend alarm pending, and
 * if so, delete it from the config if it has expired.
@@ -1974,7 +1993,7 @@ KAlarm::UpdateResult runKOrganizer()
             status.set(KAlarm::UPDATE_KORG_ERRSTART, korgInterface->lastError().message());
             qCWarning(KALARM_LOG) << "Unable to access " KORG_DBUS_PATH " D-Bus interface:" << status.message;
             delete korgInterface;
-            korgInterface = Q_NULLPTR;
+            korgInterface = nullptr;
         }
     }
     return status;
